/*
 * Copyright 2013 Andrea "andynaz" Agnesse
 * 
 * This file is part of "iRex DR1000 Merger".
 * 
 * "iRex DR1000 Merger" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 * 
 * "iRex DR1000 Merger" is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * "iRex DR1000 Merger".  If not, see <http://www.gnu.org/licenses/>.
 * 
 * author e-mail: andynaz@gmail.com
 * author home page: http://andynaz.altervista.org
 * program official page: http://andynaz.altervista.org/Progetti/iRexDR1000Merger.shtm
 */

package it.andynaz.irex.dr1000.scribble;

import java.io.*;
import java.util.*;
import com.lowagie.text.pdf.PdfContentByte;

/**
 * Represent a page of scribbles.
 * 
 * The scribbles are organized as a list of {@link Stroke} objects.
 *
 * @author andynaz
 * @version 2013-01-16
 */
public class Page {
	private List<Stroke> lStroke = new ArrayList<Stroke>();

	/**
	 * Creates a new Page object.
	 */
	public Page(){ }

	/**
	 * Add a stroke.
	 * 
	 * @param s the stroke to add
	 */
	public void addStroke(Stroke s){
		lStroke.add(s);
	}

	/**
	 * Draw all the strokes of this page.
	 * 
	 * @param cb the content of the PDF
	 * @param xAdjust the parameter to adjust the 'x' coordinates of the strokes
	 * @param yAdjust the parameter to adjust the 'y' coordinates of the strokes
	 */
	public void drawStrokes(PdfContentByte cb, float xAdjust, float yAdjust) {
		for( Stroke stroke : lStroke ){
			stroke.draw(cb, xAdjust, yAdjust);
		}
	}

}
