/*
 * Copyright 2013 Andrea "andynaz" Agnesse
 * 
 * This file is part of "iRex DR1000 Merger".
 * 
 * "iRex DR1000 Merger" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 * 
 * "iRex DR1000 Merger" is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * "iRex DR1000 Merger".  If not, see <http://www.gnu.org/licenses/>.
 * 
 * author e-mail: andynaz@gmail.com
 * author home page: http://andynaz.altervista.org
 * program official page: http://andynaz.altervista.org/Progetti/iRexDR1000Merger.shtm
 */

package it.andynaz.irex.dr1000.scribble;

import java.util.List;

/**
 * Usefull methods.
 *
 * @author andynaz
 * @version 2013-01-16
 */
public class Util {

	/**
	 * Transform 4 bytes in an int.
	 *
	 * The 4 bytes are treated in inverse order, like "i4 i3 i2 i1", considering
	 * the bits of each one. Each int must represent a byte, so its value must be
	 * included in the range [0, 255].
	 *
	 * @param i1 an int representing a byte
	 * @param i2 an int representing a byte
	 * @param i3 an int representing a byte
	 * @param i4 an int representing a byte
	 * @return the int correspong to the 4 bytes' bits
	 * 
	 * @throws IllegalArgumentException if at least one of the ints does not
	 * represent a byte, ie its value does not belong to the range [0, 255]
	 *
	 * @deprecated replaced by {@link #getIntFromBytes(int[])}
	 */
	@Deprecated
	public static int get4ByteInt(int i1, int i2, int i3, int i4){
		if( !( i1>=0 && i1<256 &&
				  i2>=0 && i2<256 &&
				  i3>=0 && i3<256 &&
				  i4>=0 && i4<256 ) )
			throw new IllegalArgumentException("ints do not represent bytes: i1="+i1+",i2="+i2+",i3="+i3+",i4="+i4);
		return (i1 + i2*256 + i3*256*256 + i4*256*256*256);
	}

	/**
	 * Transform a series of bytes in an int.
	 *
	 * The bytes are treated in inverse order, like "... i3 i2 i1", considering
	 * the bits of each one. Each int must represent a byte, so its value must be
	 * included in the range [0, 255].
	 *
	 * @param x ints representing bytes
	 * @return the int correspong to the bytes' bits
	 * 
	 * @throws IllegalArgumentException if at least one of the ints does not
	 * represent a byte, ie its value does not belong to the range [0, 255]
	 */
	public static int getIntFromBytes(int... x){
		for( int i : x)
			if( !( i>=0 && i<256 ) )
				throw new IllegalArgumentException("ints do not represent bytes");
		
		int s = 0;
		int p = 1;
		for( int i : x ){
			s += i * p;
			p *= 256;  // p=256^i
		}
		return s;
	}

	/**
	 * Transform 4 bytes in a float.
	 *
	 * The 4 bytes are treated in inverse order, like "i4 i3 i2 i1", considering
	 * the bits of each one. Each int must represent a byte, so its value must be
	 * included in the range [0, 255].
	 * 
	 * <p>The 32 bits are converted according to the IEEE 754 floating-point
	 * "single format" bit layout, using the {@link Float#intBitsToFloat(int)}
	 * method.</p>
	 *
	 * @param i1 valore compreso nell'intervallo [0,255]
	 * @param i2 valore compreso nell'intervallo [0,255]
	 * @param i3 valore compreso nell'intervallo [0,255]
	 * @param i4 valore compreso nell'intervallo [0,255]
	 * @return il valore del float corrispondente alla sequenza di bit dei 4 byte
	 */
	public static float get4ByteFloat(int i1, int i2, int i3, int i4){
		return Float.intBitsToFloat(get4ByteInt(i1, i2, i3, i4));
	}

	/**
	 * Remove the first <i>n</i> elements from a list.
	 *
	 * @param l collection from whom remove the elements
	 * @param n number of elements to remove
	 */
	public static void skip(List l, int n){
		for( int c=0; c<n; c++ )
			l.remove(0);
	}
}
